==> haskell-hslua-module-text-1.1.0.1-22-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-module-text
version:              1.1.0.1
visibility:           public
id:                   hslua-module-text-1.1.0.1-3JiAz5a0afWLshrL7Aovgn
key:                  hslua-module-text-1.1.0.1-3JiAz5a0afWLshrL7Aovgn
license:              MIT
copyright:            © 2017–2023 Albert Krewinkel
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua
synopsis:             Lua module for text
description:
    UTF-8 aware subset of Lua'\''s `string` module.

    This package is part of HsLua, a Haskell framework
    built around the embeddable scripting language
    <https://lua.org Lua>.

category:             Foreign
abi:                  8aaa892c993d45194c9c623df7291d85
exposed:              True
exposed-modules:      HsLua.Module.Text
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hslua-module-text-1.1.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hslua-module-text-1.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-text
hs-libraries:         HShslua-module-text-1.1.0.1-3JiAz5a0afWLshrL7Aovgn
depends:
    base-4.16.4.0 hslua-core-2.3.1-IyI9OufFuBtHH3ZMlxCaYs
    hslua-marshalling-2.3.0-Ig2P4Cxc1BcAg3kht9VCbg
    hslua-packaging-2.3.1-IUoPNcKfN1bCEmWPniFc9y text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-text/html/hslua-module-text.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-text/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-module-text-1.1.0.1-35.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-module-text
version:              1.1.0.1
visibility:           public
id:                   hslua-module-text-1.1.0.1-5Kn0Ue1eTL25OxpZBoxoei
key:                  hslua-module-text-1.1.0.1-5Kn0Ue1eTL25OxpZBoxoei
license:              MIT
copyright:            © 2017–2023 Albert Krewinkel
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua
synopsis:             Lua module for text
description:
    UTF-8 aware subset of Lua'\''s `string` module.

    This package is part of HsLua, a Haskell framework
    built around the embeddable scripting language
    <https://lua.org Lua>.

category:             Foreign
abi:                  a171f289d83aec50a45087aee4745965
exposed:              True
exposed-modules:      HsLua.Module.Text
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hslua-module-text-1.1.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hslua-module-text-1.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-text
hs-libraries:         HShslua-module-text-1.1.0.1-5Kn0Ue1eTL25OxpZBoxoei
depends:
    base-4.16.4.0 hslua-core-2.3.1-8C0aoFQaOrXKTRw02glTvW
    hslua-marshalling-2.3.1-KsyI9r2uX5jHis6xOiGZDK
    hslua-packaging-2.3.1-DcKYMvh8UnK4G3weiYwSG text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-text/html/hslua-module-text.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-text/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
